@@ -1,10 +1,16 @@
-# -*- coding: utf-8 -*-
 """Spatial methods."""
+
+__all__ = [
+    "get_sindex", "interp_2d_to_3d",
+    "wkt_to_dataframe", "wkt_to_geodataframe", "wkt_to_geoseries",
+    "force_2d", "round_coords", "compare_crs", "get_crs",
+    "find_segnum_in_swn"
+]
+
 import geopandas
 import numpy as np
 import pandas as pd
 import pyproj
-
 from shapely import wkt
 from shapely.geometry import Point
 
@@ -26,7 +32,7 @@ rtree_threshold = 100
 def get_sindex(gdf):
     """Get or build an R-Tree spatial index.
 
-    Particularly useful for geopandas<0.2.0;>0.7.0
+    Particularly useful for geopandas<0.2.0;>0.7.0;0.9.0
     """
     sindex = None
     if (hasattr(gdf, '_rtree_sindex')):
@@ -37,19 +43,20 @@ def get_sindex(gdf):
     elif isinstance(gdf, geopandas.GeoSeries) and hasattr(gdf, 'sindex'):
         sindex = gdf.sindex
     if sindex is not None:
-        if hasattr(sindex, 'nearest'):
-            # probably rtree.index.Index or future PyGEOSSTRTreeIndex method
+        if (hasattr(sindex, "nearest") and
+                sindex.__class__.__name__ != "PyGEOSSTRTreeIndex"):
+            # probably rtree.index.Index
             return sindex
         else:
-            # probably PyGEOSSTRTreeIndex from geopandas>=0.7.0
-            # but unfortunately, 'nearest' is required
+            # probably PyGEOSSTRTreeIndex but unfortunately, 'nearest'
+            # with 'num_results' is required
             sindex = None
     if rtree and len(gdf) >= rtree_threshold:
         # Manually populate a 2D spatial index for speed
         sindex = Index()
         # slow, but reliable
-        for idx, (segnum, row) in enumerate(gdf.bounds.iterrows()):
-            sindex.add(idx, tuple(row))
+        for idx, item in enumerate(gdf.bounds.itertuples()):
+            sindex.add(idx, item[1:])
         # cache the index for later
         setattr(gdf, '_rtree_sindex', sindex)
     return sindex
@@ -62,7 +69,7 @@ def interp_2d_to_3d(gs, grid, gt):
     ----------
     gs : geopandas.GeoSeries
         Input geopandas GeoSeries
-    grid : np.ndarray
+    grid : array_like
         2D array of values, e.g. DEM
     gt : tuple
         GDAL-style geotransform coefficients for grid
@@ -92,8 +99,7 @@ def interp_2d_to_3d(gs, grid, gt):
             (x < gt[0]) | (x > (gt[0] + nx * gt[1])) |
             (y > gt[3]) | (y < (gt[3] + ny * gt[5])))
         if outside.any():
-            raise ValueError('{0} coordinates are outside grid'
-                             .format(outside.sum()))
+            raise ValueError(f'{outside.sum()} coordinates are outside grid')
         # Use half raster cell widths for cell center values
         fx = (x - (gt[0] + hx)) / gt[1]
         fy = (y - (gt[3] + hy)) / gt[5]
@@ -152,6 +158,9 @@ def round_coords(gs, rounding_precision=3):
     return wkt_to_geoseries(
             gs.apply(wkt.dumps, rounding_precision=rounding_precision))
 
+def visible_wkt(geom):
+    """Re-generate geometry to only visible WKT, erase machine precision."""
+    return wkt.loads(geom.wkt)
 
 def compare_crs(sr1, sr2):
     """Compare two crs, flexible on crs type."""
@@ -206,7 +215,7 @@ def find_segnum_in_swn(n, geom):
         (if catchments are found) is_within_catchment.
 
     """
-    from swn.base import SurfaceWaterNetwork
+    from swn.core import SurfaceWaterNetwork
 
     if not isinstance(n, SurfaceWaterNetwork):
         raise TypeError('expected an instance of SurfaceWaterNetwork')
