@@ -1,6 +1,7 @@
-# -*- coding: utf-8 -*-
 """Miscellaneous utility functions that don't fit anywhere else."""
 
+__all__ = ["abbr_str"]
+
 
 def abbr_str(lst, limit=15):
     """Return str of list that is abbreviated (if necessary)."""
@@ -22,6 +23,6 @@ def abbr_str(lst, limit=15):
             [str(x) for x in lst[:left]] + ['...'] +
             [str(x) for x in lst[-right:]])
     if is_set:
-        return '{' + res + '}'
+        return f"{{{res}}}"
     else:
-        return '[' + res + ']'
+        return f"[{res}]"
